{ config, lib, pkgs, jovian, ... }:
{
  imports = [
    ./gnome
    jovian.nixosModules.default
  ];

  config = lib.mkIf config.jovian.steam.enable {
    jovian = {
      steam = {
        autoStart = true;
        user = config.vars.mainUser;
      };
      decky-loader = {
        enable = true;
        package = pkgs.decky-loader-prerelease;
      };
      devices.steamdeck = {
        enable = true;
        enableGyroDsuService = true;
      };
    };

    boot = {
      kernelPackages = lib.mkForce pkgs.linuxPackages_jovian;
      kernelParams = [ "amd_pstate=active" ];
    };

    programs.steam.extest.enable = true;

    services = {
      keyd.enable = lib.mkForce false;
      tlp.enable = lib.mkForce false;
    };

    hardware.xone.enable = true;

    networking = {
      networkmanager.enable = true;
      wireless.enable = lib.mkForce false;
    };

    environment.persistence."/persist".directories = [
      "/etc/NetworkManager/system-connections"
      "/var/lib/decky-loader"
    ];

    nixpkgs.allowUnfreePackages = [
      "steam"
      "steam-jupiter-unwrapped"
      "steamdeck-firmware"
      "steamdeck-hw-theme"
      "xow_dongle-firmware"
    ];

    specialisation.desktop.configuration.config.jovian.steam.enable = lib.mkForce false;
  };
}
